diff pidgin/gtksavedstatuses.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 760ef6d78d2d
children 66dff3dfdea6
line wrap: on
line diff
--- a/pidgin/gtksavedstatuses.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/pidgin/gtksavedstatuses.h	Mon Mar 19 07:01:17 2007 +0000
@@ -2,7 +2,7 @@
  * @file gtksavedstatuses.h GTK+ Saved Status Editor UI
  * @ingroup gtkui
  *
- * gaim
+ * purple
  *
  * Pidgin is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
@@ -50,12 +50,12 @@
  *               with the transient status using the status
  *               parameter to this function.
  * @param status If edit is TRUE then this should be a
  *               pointer to the GaimSavedStatus to edit.
  *               If edit is FALSE then this can be NULL,
  *               or you can pass in a saved status to
  *               seed the initial values of the new status.
  */
-void pidgin_status_editor_show(gboolean edit, GaimSavedStatus *status);
+void pidgin_status_editor_show(gboolean edit, PurpleSavedStatus *status);
 
 /**
  * Creates a dropdown menu of saved statuses and calls a callback
@@ -65,7 +65,7 @@
  * @param callback The callback to call when the selection changes
  * @return         The menu widget
  */
-GtkWidget *pidgin_status_menu(GaimSavedStatus *status, GCallback callback);
+GtkWidget *pidgin_status_menu(PurpleSavedStatus *status, GCallback callback);
 
 /**
  * Returns the GTK+ status handle.
@@ -50,12 +50,12 @@
  *               parameter to this function.
  * @param status If edit is TRUE then this should be a
- *               pointer to the GaimSavedStatus to edit.
+ *               pointer to the PurpleSavedStatus to edit.
  *               If edit is FALSE then this can be NULL,
  *               or you can pass in a saved status to